@@ -75,6 +75,7 @@ from .modules import RediffBolDownloaderAttack
 from .modules import RegistryPro
 from .modules import RisingScanner
 from .modules import RtspVaPgCtrl
+from .modules import ScriptingDictionary
 from .modules import ScriptingEncoder
 from .modules import ScriptingFileSystemObject
 from .modules import ShellApplication
@@ -727,6 +728,7 @@ CLSID = [
                             'responseBody'          : '',
                             'responseText'          : '',
                             'responseType'          : '',
+                            'responseURL'           : '',
                             'responseXML'           : '',
                             'response'              : '',
                             'readyState'            : 4,
@@ -1064,6 +1066,25 @@ CLSID = [
                           }
         },
 
+        # Scripting.Dictionary
+        {
+            'id'        : (),
+            'name'      : ( 'scripting.dictionary', ),
+            'attrs'     : {
+                            'Count'             : 0,
+                            'dictionary'        : {},
+                          },
+            'funcattrs' : {},
+            'methods'   : {
+                            'Add'               : ScriptingDictionary.Add,
+                            'Exists'            : ScriptingDictionary.Exists,
+                            'Items'             : ScriptingDictionary.Items,
+                            'Keys'              : ScriptingDictionary.Keys,
+                            'Remove'            : ScriptingDictionary.Remove,
+                            'RemoveAll'         : ScriptingDictionary.RemoveAll
+                          }
+        },
+
         # Scripting.Encoder
         {
             'id'        : (),
