@@ -4,7 +4,7 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def GetVersions(self):
+def GetVersions(self): # pylint:disable=unused-argument
     versions = ""
     for feature in ('Accessibility',
                     'AcroForm',
@@ -29,12 +29,12 @@ def GetVersions(self):
                     'Spelling',
                     'Updater',
                     'weblink'):
-        versions += "%s=%s," % (feature, log.ThugVulnModules.acropdf_pdf, )
+        versions += f"{feature}={log.ThugVulnModules.acropdf_pdf},"
 
     return versions
 
 
-def GetVariable(self, variable):
+def GetVariable(self, variable): # pylint:disable=unused-argument
     if variable in ('$version', ):
         return log.ThugVulnModules.acropdf_pdf
 
