@@ -6,7 +6,7 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def AddColumn(self, arg0, arg1):
+def AddColumn(self, arg0, arg1): # pylint:disable=unused-argument
     if len(arg0) > 100:
         log.ThugLogging.log_exploit_event(self._window.url,
                                           "CA BrightStor ActiveX",
