@@ -6,7 +6,7 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def DownURL2(self, arg0, *args):
+def DownURL2(self, arg0, *args): # pylint:disable=unused-argument
     if len(arg0) > 1024:
         log.ThugLogging.log_exploit_event(self._window.url,
                                           "Xunlei DPClient.Vod.1 ActiveX",
