@@ -5,7 +5,7 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def IEStartNative(self, arg0, arg1, arg2):
+def IEStartNative(self, arg0, arg1, arg2): # pylint:disable=unused-argument
     if len(arg0) > 220:
         log.ThugLogging.log_exploit_event(self._window.url,
                                           "Ourgame GLWorld GLIEDown2.dll ActiveX",
