@@ -6,8 +6,8 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def DownloadFromMusicStore(self, url, dst, title, artist, album, genere, size, param1, param2):
-    log.ThugLogging.add_behavior_warn('[JetAudio ActiveX] Downloading from URL %s (saving locally as %s)' % (url, dst, ))
+def DownloadFromMusicStore(self, url, dst, title, artist, album, genere, size, param1, param2): # pylint:disable=unused-argument
+    log.ThugLogging.add_behavior_warn(f'[JetAudio ActiveX] Downloading from URL {url} (saving locally as {dst})')
     log.ThugLogging.log_exploit_event(self._window.url,
                                       "JetAudio ActiveX",
                                       "Downloading from URL",
@@ -22,5 +22,5 @@ def DownloadFromMusicStore(self, url, dst, title, artist, album, genere, size, p
 
     try:
         self._window._navigator.fetch(url, redirect_type = "JetAudio exploit")
-    except Exception:
+    except Exception: # pylint:disable=broad-except
         log.ThugLogging.add_behavior_warn('[JetAudio ActiveX] Fetch failed')
