@@ -7,7 +7,7 @@ log = logging.getLogger("Thug")
 
 
 def setSlice(self, arg0, arg1, arg2, arg3):
-    log.ThugLogging.add_behavior_warn('[WebViewFolderIcon ActiveX] setSlice(%s, %s, %s, %s)' % (arg0, arg1, arg2, arg3, ))
+    log.ThugLogging.add_behavior_warn(f'[WebViewFolderIcon ActiveX] setSlice({arg0}, {arg1}, {arg2}, {arg3})')
     if arg0 == 0x7ffffffe:
         log.ThugLogging.log_exploit_event(self._window.url,
                                           "WebViewFolderIcon ActiveX",
