@@ -35,6 +35,7 @@ from cssutils.parse import CSSParser
 
 from thug.ActiveX.ActiveX import _ActiveXObject
 from thug.DOM.W3C import w3c
+from thug.DOM.AsyncPrefetcher import AsyncPrefetcher
 
 log = logging.getLogger("Thug")
 
@@ -91,6 +92,7 @@ class DFT:
         self.anchors           = []
         self.forms             = kwds['forms'] if 'forms' in kwds else []
         self._context          = None
+        self.async_prefetcher  = AsyncPrefetcher(window)
         log.DFT                = self
 
         self._init_events()
@@ -289,8 +291,8 @@ class DFT:
             except Exception: # pylint:disable=broad-except
                 handler = None
 
-        if not handler: # pragma: no cover
-            return
+        if not handler:
+            return # pragma: no cover
 
         if getattr(elem, 'name', None) and elem.name in ('body', ) and evt in self.window_on_events:
             setattr(self.window, evt, handler)
@@ -355,8 +357,8 @@ class DFT:
             return
 
         jnlp = soup.find("jnlp")
-        if jnlp is None: # pragma: no cover
-            return
+        if jnlp is None:
+            return # pragma: no cover
 
         codebase = jnlp.attrs['codebase'] if 'codebase' in jnlp.attrs else ''
 
@@ -367,8 +369,8 @@ class DFT:
             self._check_jnlp_param(param)
 
         jars = soup.find_all("jar")
-        if not jars: # pragma: no cover
-            return
+        if not jars:
+            return # pragma: no cover
 
         headers['User-Agent'] = self.javaWebStartUserAgent
 
@@ -384,8 +386,8 @@ class DFT:
 
         for child in _object.find_all():
             name = getattr(child, 'name', None)
-            if name is None: # pragma: no cover
-                continue
+            if name is None:
+                continue # pragma: no cover
 
             if name.lower() in ('param', ):
                 if all(p in child.attrs for p in ('name', 'value', )):
@@ -601,8 +603,8 @@ class DFT:
             log.warning("[SCRIPT] Unhandled script type: %s", language)
             return None
 
-        if _language in ("script", ): # pragma: no cover
-            _language = "javascript"
+        if _language in ("script", ):
+            _language = "javascript" # pragma: no cover
 
         return getattr(self, f"handle_{_language}", None)
 
@@ -678,8 +680,8 @@ class DFT:
 
     def handle_data_javascript(self, script, src):
         data = self._handle_data_uri(src)
-        if data is None: # pragma: no cover
-            return
+        if data is None:
+            return # pragma: no cover
 
         s = self.window.doc.createElement('script')
 
@@ -707,8 +709,8 @@ class DFT:
             log.info("[ERROR][handle_external_javascript] %s", str(e))
             return
 
-        if response is None or not response.ok or not response.content: # pragma: no cover
-            return
+        if response is None or not response.ok or not response.content:
+            return # pragma: no cover
 
         if log.ThugOpts.code_logging:
             log.ThugLogging.add_code_snippet(response.content, 'Javascript', 'External')
@@ -872,8 +874,8 @@ class DFT:
             log.ThugLogging.Features.increase_url_count()
 
         _action = log.HTTPSession.normalize_url(self.window, action)
-        if _action is None: # pragma: no cover
-            return
+        if _action is None:
+            return # pragma: no cover
 
         if _action not in self.forms:
             self.forms.append(_action)
@@ -907,8 +909,8 @@ class DFT:
         if response is None or not response.ok:
             return
 
-        if getattr(response, 'thug_mimehandler_hit', False): # pragma: no cover
-            return
+        if getattr(response, 'thug_mimehandler_hit', False):
+            return # pragma: no cover
 
         doc    = w3c.parseString(response.content)
         window = Window(_action, doc, personality = log.ThugOpts.useragent)
@@ -1051,14 +1053,14 @@ class DFT:
             if s.lower().startswith('url='):
                 url = s[4:]
 
-        if not url: # pragma: no cover
-            return
+        if not url:
+            return # pragma: no cover
 
         if url.startswith("'") and url.endswith("'"):
             url = url[1:-1]
 
-        if url in log.ThugLogging.meta and log.ThugLogging.meta[url] >= 3: # pragma: no cover
-            return
+        if url in log.ThugLogging.meta and log.ThugLogging.meta[url] >= 3:
+            return # pragma: no cover
 
         if data_uri:
             self._handle_data_uri(url)
@@ -1117,7 +1119,7 @@ class DFT:
             log.info("[ERROR][handle_frame] %s", str(e))
             return
 
-        if response is None or not response.ok: # pragma: no cover
+        if response is None or not response.ok:
             return # pragma: no cover
 
         if response.url in log.ThugLogging.frames and log.ThugLogging.frames[response.url] >= 3:
@@ -1161,8 +1163,8 @@ class DFT:
             if log.ThugOpts.features_logging:
                 log.ThugLogging.Features.increase_url_count()
 
-            if self._handle_data_uri(url): # pragma: no cover
-                continue
+            if self._handle_data_uri(url):
+                continue # pragma: no cover
 
             try:
                 self.window._navigator.fetch(url, redirect_type = "font face")
@@ -1213,8 +1215,8 @@ class DFT:
             log.ThugLogging.Features.increase_data_uri_count()
 
         h = uri.split(",")
-        if len(h) < 2 or not h[1]: # pragma: no cover
-            return None
+        if len(h) < 2 or not h[1]:
+            return None # pragma: no cover
 
         data = h[1]
         opts = h[0][len("data:"):].split(";")
@@ -1261,8 +1263,8 @@ class DFT:
             return
 
         href = anchor.get('href', None)
-        if not href: # pragma: no cover
-            return
+        if not href:
+            return # pragma: no cover
 
         if self._handle_data_uri(href):
             return
@@ -1273,12 +1275,12 @@ class DFT:
             log.info("[ERROR][handle_a] %s", str(e))
             return
 
-        if response is None or not response.ok: # pragma: no cover
-            return
+        if response is None or not response.ok:
+            return # pragma: no cover
 
         content_type = response.headers.get('content-type', None)
-        if not content_type: # pragma: no cover
-            return
+        if not content_type:
+            return # pragma: no cover
 
         if content_type.startswith(('text/html', )):
             from .Window import Window
@@ -1292,15 +1294,29 @@ class DFT:
     def handle_link(self, link):
         log.info(link)
 
+        # When a browser requests a resource from a third party server, that cross-origin’s
+        # domain name must be resolved to an IP address before the browser can issue the
+        # request. This process is known as DNS resolution. While DNS caching can help to
+        # reduce this latency, DNS resolution can add significant latency to requests. For
+        # websites that open connections to many third parties, this latency can significantly
+        # reduce loading performance.
+        #
+        # dns-prefetch helps developers mask DNS resolution latency. The HTML <link> element
+        # offers this functionality by way of a rel attribute value of dns-prefetch. The
+        # cross-origin domain is then specified in the href attribute
+        rel = link.get('rel', None)
+        if rel and any(r in ('dns-prefetch', ) for r in rel):
+            return # pragma: no cover
+
         href = link.get('href', None)
-        if not href: # pragma: no cover
-            return
+        if not href:
+            return # pragma: no cover
 
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_url_count()
 
-        if self._handle_data_uri(href): # pragma: no cover
-            return
+        if self._handle_data_uri(href):
+            return # pragma: no cover
 
         try:
             self.window._navigator.fetch(href, redirect_type = "link")
@@ -1311,23 +1327,23 @@ class DFT:
         if not log.ThugOpts.image_processing:
             return
 
-        if not log.MIMEHandler.image_ocr_enabled and not log.MIMEHandler.image_hook_enabled: # pragma: no cover
-            return
+        if not log.MIMEHandler.image_ocr_enabled and not log.MIMEHandler.image_hook_enabled:
+            return # pragma: no cover
 
         log.info(img)
         src = img.get('src', None)
-        if not src: # pragma: no cover
-            return
+        if not src:
+            return # pragma: no cover
 
-        if self._handle_data_uri(src): # pragma: no cover
-            return
+        if self._handle_data_uri(src):
+            return # pragma: no cover
 
         cache = getattr(self, 'img_cache', None)
         if not cache:
             self.img_cache = set()
 
-        if src in self.img_cache: # pragma: no cover
-            return
+        if src in self.img_cache:
+            return # pragma: no cover
 
         self.img_cache.add(src)
 
@@ -1346,8 +1362,8 @@ class DFT:
         for anchor in clicked_anchors:
             del anchor['_clicked']
 
-            if 'href' not in anchor.attrs: # pragma: no cover
-                continue
+            if 'href' not in anchor.attrs:
+                continue # pragma: no cover
 
             href = anchor.attrs['href']
             self.follow_href(href)
@@ -1406,8 +1422,8 @@ class DFT:
             return
 
         attrs = getattr(element, 'attrs', None)
-        if attrs is None: # pragma: no cover
-            return
+        if attrs is None:
+            return # pragma: no cover
 
         attrs_count = 0
         element_area = 1
@@ -1443,12 +1459,21 @@ class DFT:
         except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.info("[ERROR][run_htmlclassifier] %s", str(e))
 
+    def async_prefetch(self, soup):
+        for script in soup.find_all('script'):
+            src = script.get('src', None)
+            if src:
+                self.async_prefetcher.fetch(src)
+
     def _run(self, soup = None):
         if soup is None:
             soup = self.window.doc.doc
 
         _soup = soup
 
+        if log.ThugOpts.async_prefetch:
+            self.async_prefetch(soup)
+
         # Dirty hack
         for p in soup.find_all('object'):
             self.check_hidden_element(p)
@@ -1460,8 +1485,8 @@ class DFT:
             self.handle_applet(p)
 
         for child in soup.descendants:
-            if child is None: # pragma: no cover
-                continue
+            if child is None:
+                continue # pragma: no cover
 
             self.check_hidden_element(child)
 
