@@ -37,7 +37,24 @@ class HTMLInspector:
         with open(conf_file, encoding = 'utf-8', mode = 'r') as fd:
             self.rules = json.load(fd)
 
+    @staticmethod
+    def check_ignore_handler(html):
+        ignore_handlers = (
+			log.MIMEHandler.passthrough,
+			log.MIMEHandler.handle_zip,
+			log.MIMEHandler.handle_rar,
+			log.MIMEHandler.handle_java_jnlp,
+			log.MIMEHandler.handle_json,
+			log.MIMEHandler.handle_image)
+
+        mtype = log.Magic.get_mime(html)
+        handler = log.MIMEHandler.get_handler(mtype)
+        return handler in ignore_handlers
+
     def run(self, html, parser = "html.parser"):
+        if self.check_ignore_handler(html):
+            return bs4.BeautifulSoup()
+
         if self.enabled and html:
             self.inspect(html, parser)
 
