@@ -114,5 +114,9 @@ class JSInspector:
         except Exception as e: # pylint:disable=broad-except
             log.warning("[JSInspector] %s", str(e))
 
-        self.dump()
+        try:
+            self.dump()
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
+            log.warning("[JSInspector] Dumping failed (%s)", str(e))
+
         return result
