@@ -67,8 +67,12 @@ class MIMEHandler(dict):
         application/pdf Content-Type handler.
     """
 
+    MB = 1024 * 1024
+
     MIN_ZIP_FILE_SIZE = 32
+    MAX_ZIP_FILE_SIZE = 32 * MB
     MIN_RAR_FILE_SIZE = 32
+    MAX_RAR_FILE_SIZE = 32 * MB
     MIN_IMG_FILE_SIZE = 32
 
     mimetypes = ("application/atom+xml",
@@ -79,10 +83,8 @@ class MIMEHandler(dict):
                  "application/futuresplash",
                  "application/internet-property-stream",
                  "application/java-archive",
-                 "application/javascript",
                  "application/mac-binhex40",
                  "application/msword",
-                 "application/octet-stream",
                  "application/oda",
                  "application/olescript",
                  "application/pdf",
@@ -90,7 +92,6 @@ class MIMEHandler(dict):
                  "application/pkcs10",
                  "application/pkix-crl",
                  "application/postscript",
-                 "application/rar",
                  "application/rss+xml",
                  "application/rtf",
                  "application/set-payment-initiation",
@@ -116,13 +117,13 @@ class MIMEHandler(dict):
                  "application/x-director",
                  "application/x-dosexec",
                  "application/x-dvi",
+                 "application/x-empty",
+                 "application/x-executable",
                  "application/x-gtar",
                  "application/x-gzip",
                  "application/x-hdf",
                  "application/x-internet-signup",
                  "application/x-iphone",
-                 "application/x-java-jnlp-file",
-                 "application/x-javascript",
                  "application/x-latex",
                  "application/x-msaccess",
                  "application/x-mscardfile",
@@ -143,7 +144,6 @@ class MIMEHandler(dict):
                  "application/x-pkcs7-certreqresp",
                  "application/x-pkcs7-mime",
                  "application/x-pkcs7-signature",
-                 "application/x-rar-compressed",
                  "application/x-sh",
                  "application/x-shar",
                  "application/x-shockwave-flash",
@@ -165,7 +165,6 @@ class MIMEHandler(dict):
                  "application/x-xpinstall",
                  "application/x-zip-compressed",
                  "application/ynd.ms-pkipko",
-                 "application/zip",
                  "audio/basic",
                  "audio/mid",
                  "audio/mpeg",
@@ -174,16 +173,11 @@ class MIMEHandler(dict):
                  "audio/x-ms-wma",
                  "audio/x-pn-realaudio",
                  "audio/x-wav",
-                 "image/bmp",
                  "image/bmpimage/x-bmp",
                  "image/cis-cod",
-                 "image/gif",
                  "image/ief",
-                 "image/jpeg",
                  "image/pipeg",
-                 "image/png",
                  "image/svg+xml",
-                 "image/tiff",
                  "image/x-cmu-raster",
                  "image/x-cmx",
                  "image/x-icon",
@@ -196,12 +190,8 @@ class MIMEHandler(dict):
                  "image/x-xpixmap",
                  "image/x-xwindowdump",
                  "message/rfc822",
-                 "text/css",
                  "text/h323",
-                 "text/html",
                  "text/iuls",
-                 "text/javascript",
-                 "text/plain",
                  "text/richtext",
                  "text/scriptlet",
                  "text/tab-separated-values",
@@ -211,6 +201,7 @@ class MIMEHandler(dict):
                  "text/x-component",
                  "text/x-setext",
                  "text/x-vcard",
+                 "video/mp4",
                  "video/mpeg",
                  "video/quicktime",
                  "video/x-la-asf",
@@ -284,6 +275,7 @@ class MIMEHandler(dict):
         self.register_handler('application/zip', self.handle_zip)
 
     def register_rar_handlers(self):
+        self.register_handler('application/rar', self.handle_rar)
         self.register_handler('application/x-rar-compressed', self.handle_rar)
 
     def register_java_jnlp_handlers(self):
@@ -359,6 +351,9 @@ class MIMEHandler(dict):
         if len(content) < self.MIN_ZIP_FILE_SIZE: # pragma: no cover
             return False
 
+        if len(content) > self.MAX_ZIP_FILE_SIZE: # pragma: no cover
+            return False
+
         fp = io.BytesIO(content)
         if not zipfile.is_zipfile(fp):
             return False
@@ -416,6 +411,9 @@ class MIMEHandler(dict):
         if len(content) < self.MIN_RAR_FILE_SIZE: # pragma: no cover
             return False
 
+        if len(content) > self.MAX_RAR_FILE_SIZE: # pragma: no cover
+            return False
+
         fd, rfile = tempfile.mkstemp()
         with open(rfile, 'wb') as fd:
             fd.write(content)
