@@ -30,10 +30,10 @@ class SchemeHandler:
 
         window.evalScript(hcp[0])
 
-    def handle_res(self, window, url):
+    def handle_res(self, window, url): # pylint:disable=unused-argument
         log.warning('Microsoft Internet Explorer RES Scheme Detected')
 
         try:
             log.URLClassifier.classify(url)
-        except Exception: # pragma: no cover
+        except Exception: # pragma: no cover,pylint:disable=broad-except
             pass
