@@ -9,6 +9,7 @@ from thug.DOM.W3C.Style.CSS.ElementCSSInlineStyle import ElementCSSInlineStyle
 
 from .DOMException import DOMException
 from .Node import Node
+from .ClassList import ClassList
 
 log = logging.getLogger("Thug")
 
@@ -50,6 +51,8 @@ class Element(Node, ElementCSSInlineStyle):
             return
 
     def __init_element_personality_IE(self):
+        self.clearAttributes = self._clearAttributes
+
         if log.ThugOpts.Personality.browserMajorVersion > 7:
             self.querySelectorAll = self._querySelectorAll
             self.querySelector    = self._querySelector
@@ -57,14 +60,14 @@ class Element(Node, ElementCSSInlineStyle):
         if log.ThugOpts.Personality.browserMajorVersion > 8:
             self.getElementsByClassName = self._getElementsByClassName
             self.msMatchesSelector      = self._matches
-            self.classList              = property(self._classList)
+            self.classList              = ClassList(self.tag)
 
     def __init_element_personality_Firefox(self):
         self.querySelectorAll       = self._querySelectorAll
         self.querySelector          = self._querySelector
         self.mozMatchesSelector     = self._matches
         self.getElementsByClassName = self._getElementsByClassName
-        self.classList              = property(self._classList)
+        self.classList              = ClassList(self.tag)
 
         if log.ThugOpts.Personality.browserMajorVersion > 33:
             self.matches = self._matches
@@ -74,7 +77,7 @@ class Element(Node, ElementCSSInlineStyle):
         self.querySelector          = self._querySelector
         self.webkitMatchesSelector  = self._matches
         self.getElementsByClassName = self._getElementsByClassName
-        self.classList              = property(self._classList)
+        self.classList              = ClassList(self.tag)
 
         if log.ThugOpts.Personality.browserMajorVersion > 33:
             self.matches = self._matches
@@ -83,7 +86,7 @@ class Element(Node, ElementCSSInlineStyle):
         self.querySelectorAll       = self._querySelectorAll
         self.querySelector          = self._querySelector
         self.getElementsByClassName = self._getElementsByClassName
-        self.classList              = property(self._classList)
+        self.classList              = ClassList(self.tag)
 
         if log.ThugOpts.Personality.browserMajorVersion > 6:
             self.matches = self._matches
@@ -156,10 +159,6 @@ class Element(Node, ElementCSSInlineStyle):
     def scrollHeight(self):
         return random.randint(10, 100)
 
-    def _classList(self):
-        from .ClassList import ClassList
-        return ClassList(self.tag)
-
     # Introduced in DOM Level 2
     def hasAttribute(self, name):
         return self.tag.has_attr(name)
@@ -268,6 +267,19 @@ class Element(Node, ElementCSSInlineStyle):
         if name in self.tag.attrs:
             del self.tag.attrs[name]
 
+    def _clearAttributes(self):
+        from thug.DOM.W3C.Events.HTMLEvent import HTMLEvent
+        from thug.DOM.W3C.Events.MouseEvent import MouseEvent
+
+        no_clear = {'id', 'name', 'style', 'value', }
+        for events in (HTMLEvent.EventTypes, MouseEvent.EventTypes, ):
+            for e in events:
+                no_clear.add(f'on{e}')
+
+        names = [name for name in self.tag.attrs if name not in no_clear]
+        for name in names:
+            self.removeAttribute(name)
+
     def getAttributeNode(self, name):
         from .Attr import Attr
         return Attr(self.doc, self, name) if name in self.tag.attrs else None
