@@ -9,4 +9,4 @@ class abstractmethod:
 
     def __call__(self, *args, **kwds): # pragma: no cover
         func_name = self.func.__name__ if sys.version_info.major >= 3 else self.func.func_name
-        raise NotImplementedError("method %s is abstract." % func_name)
+        raise NotImplementedError(f"Method {func_name} is abstract.")
