@@ -27,7 +27,7 @@ class HTMLDocument(Document):
         Document.__init__(self, doc)
 
         self._win           = win
-        self._body          = HTMLBodyElement(self.doc, self.doc.find('body'))
+        self.body           = HTMLBodyElement(self.doc, self.doc.find('body'))
         self._referer       = referer
         self._lastModified  = lastModified
         self._cookie        = cookie
@@ -129,10 +129,6 @@ class HTMLDocument(Document):
 
     window = property(getWindow, setWindow)
 
-    @property
-    def body(self):
-        return self._body
-
     @property
     def tag(self):
         return self
@@ -454,7 +450,7 @@ class HTMLDocument(Document):
     def _all(self):
         from .HTMLAllCollection import HTMLAllCollection
 
-        s = list(self.doc.find_all(text = False))
+        s = list(self.doc.find_all(string = False))
         return HTMLAllCollection(self.doc, s)
 
     @property
