@@ -16,7 +16,7 @@ class HTMLScriptElement(HTMLElement):
     htmlFor = None
     event   = None
     charset = attr_property("charset", default = "")
-    defer   = bool_property("defer", readonly = True, novalue = True)
+    defer   = bool_property("defer", novalue = True)
     _src    = attr_property("src", default = "")
     type    = attr_property("type")
 
