@@ -616,24 +616,6 @@ class IThugAPI(zope.interface.Interface):
         @return: None
         """
 
-    def set_vt_query():
-        """
-        set_vt_query
-
-        Enable VirusTotal queries for sample analysis
-
-        @return: None
-        """
-
-    def set_vt_submit():
-        """
-        set_vt_submit
-
-        Enable VirusTotal samples submit
-
-        @return: None
-        """
-
     def get_web_tracking():
         """
         get_web_tracking
@@ -652,6 +634,33 @@ class IThugAPI(zope.interface.Interface):
         @return: None
         """
 
+    def get_async_prefetch():
+        """
+        get_async_prefetch
+
+        Return True if asynchronous prefetching mode is enabled, False otherwise.
+
+        @return: bool
+        """
+
+    def set_async_prefetch():
+        """
+        set_async_prefetch
+
+        Enable asynchronous prefetching mode
+
+        @return: None
+        """
+
+    def reset_async_prefetch():
+        """
+        set_async_prefetch
+
+        Disable asynchronous prefetching mode
+
+        @return: None
+        """
+
     def add_urlclassifier(rule):
         """
         add_urlclassifier
